# mjbots meshes

## License

Files in this directory are under the Apache 2.0 license. They are adapted from the following files distributed by [mjbots](https://mjbots.com/):

- [mj5208 CAD model](https://a360.co/3sVprW3)
- [qdd100 STEP file](https://drive.google.com/file/d/1678YxQfFQZzw0SReEfnle-s26x3cyDuh/view?usp=sharing).
- [qdd100 horn STEP file](https://drive.google.com/file/d/1Uup_2laLZXq2O5Lu7b4f5lgfOKkbsESV/view?usp=sharing)

## Changes

- Separate stator and rotor for the mj5208 model
- Separate stator and rotor for the qdd100 model
